@@ -16,7 +16,7 @@ from utilities.forms import (
 )
 
 from netbox_storage.models import Drive
-from virtualization.models import Cluster, VirtualMachine
+from virtualization.models import Cluster, ClusterType, VirtualMachine
 
 
 class DriveForm(NetBoxModelForm):
@@ -28,7 +28,9 @@ class DriveForm(NetBoxModelForm):
         validators=[MinValueValidator(1)],
     )
     cluster = DynamicModelChoiceField(
-        queryset=Cluster.objects.all(),
+        queryset=Cluster.objects.filter(
+            type=ClusterType.objects.filter(name="Storage").first(),
+        ),
         required=False,
         query_params={
             'site_id': '$site',
